%define major		4
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Summary:	Gets a file from an FTP, GOPHER or HTTP server
Name:		curl
Epoch:		1
Version:	7.88.1
%define subrel 3
Release:	%mkrel 4
License:	BSD-like
Group:		Networking/Other
URL:		https://curl.haxx.se
Source0:	https://curl.haxx.se/download/%{name}-%{version}.tar.xz
Source1:	https://curl.haxx.se/download/%{name}-%{version}.tar.xz.asc
# Patch from Fedora - thanks!
# See https://curl.haxx.se/mail/lib-2019-01/0000.html .
Patch1:		0105-curl-7.63.0-libstubgss-ldadd.patch
Patch4:		curl-7.58.0-multilib.patch
Patch7:		curl-7.78.0-debug.patch
Patch8:		CVE-2023-27533.patch
Patch9:		CVE-2023-27534.patch
Patch10:	CVE-2023-27538.patch
Patch11:	CVE-2023-27535.patch
Patch12:	CVE-2023-27536.patch
Patch13:	CVE-2023-27537.patch
Patch14:	CVE-2023-28319.patch
Patch15:	CVE-2023-28320.patch
Patch16:	CVE-2023-28320-1.patch
Patch17:	CVE-2023-28321.patch
Patch18:	CVE-2023-28322.patch
Patch19:	CVE-2023-32001.patch
Patch20:	CVE-2023-38039.patch
Patch21:	CVE-2023-38545_7.87.0.patch
Patch22:	CVE-2023-38546.patch
Patch23:	CVE-2023-46218.patch
Patch24:	CVE-2023-46219.patch
Patch25:	CVE-2024-2004.patch
Patch26:	CVE-2024-2398.patch
BuildRequires:	groff-for-man
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libbrotlidec)
BuildRequires:	pkgconfig(libidn2)
BuildRequires:	pkgconfig(libpsl)
BuildRequires:	pkgconfig(libssh)
BuildRequires:	pkgconfig(python3)
BuildRequires:	openldap-devel
BuildRequires:	pkgconfig(krb5)
#BuildRequires:	c-ares-devel
# (misc) required for testing
BuildRequires:	stunnel
BuildRequires:  pkgconfig(libnghttp2) >= 1.35.0
Provides:	webfetch

%description
curl is a client to get documents/files from servers, using any of the
supported protocols. The command is designed to work without user
interaction or any kind of interactivity.

curl offers a busload of useful tricks like proxy support, user
authentication, ftp upload, HTTP post, file transfer resume and more.

%package -n	%{libname}
Summary:	A library of functions for file transfer
Group:		Networking/Other
Requires:	rootcerts >= 1:20070713.00

%description -n	%{libname}
libcurl is a library of functions for sending and receiving files through
various protocols, including http and ftp.

%package -n	%{develname}
Summary:	Header files and libraries for libcurl
Group:		Development/C
Requires:	%{libname} = %{epoch}:%{version}-%{release}
Provides:	%{name}-devel = %{epoch}:%{version}-%{release}
Provides:	lib%{name}-devel = %{epoch}:%{version}-%{release}
Provides:	libcurl%{major}-devel = %{epoch}:%{version}-%{release}
Provides:	%mklibname %{name} 4 -d

%description -n	%{develname}
libcurl is a library of functions for sending and receiving files through
various protocols, including http and ftp.

You should install this package if you wish to develop applications that
use libcurl.

%package	examples
Summary:	Example files for %{name} development
Group:		Development/C
BuildArch:	noarch
Requires:	%{name}-devel >= %{epoch}:%{version}-%{release}

%description	examples
Example files for %{name} development.

%prep
%setup -q
%autopatch -p1

# Remove ldflags from curl-config output
sed -i -e 's/@LDFLAGS@\s\+//g' curl-config.in

%build
autoreconf -fiv

%configure \
	--disable-static \
	--with-brotli \
	--with-libidn2 \
	--with-libpsl \
	--with-ssl \
	--without-gnutls \
	--with-zlib \
	--with-lber-lib=lber \
	--with-libssh \
	--with-random \
	--enable-hidden-symbols \
	--enable-optimize \
	--enable-nonblocking \
	--enable-thread \
	--enable-crypto-auth \
	--enable-libgcc \
	--enable-ldaps \
	--enable-ipv6 \
	--with-ca-bundle=%{_sysconfdir}/pki/tls/certs/ca-bundle.crt \
	--with-gssapi \
	--disable-ares \
	--with-nghttp2

%make_build

%ifnarch %arm
# disable tests that want to connect/run sshd, which is not possible
%check
skip_tests='true'
if ! "$skip_tests" ; then
    # %make_build sets -O which effectively hides the test output
    %__make %{?_smp_mflags} test V=0 TEST_Q='-a -p -v !flaky !SCP !SFTP !SOCKS4 !SOCKS5 !TFTP !198 !323 !2034 !1139 !1140 !1560'
fi
%endif

%install
%make_install

find %{buildroot} -name *.la -delete

%files
%{_bindir}/curl
%{_mandir}/man1/curl.1*

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%doc docs/BUGS.md docs/KNOWN_BUGS docs/CONTRIBUTE.md docs/FAQ CHANGES
%doc docs/TODO docs/THANKS docs/INTERNALS.md
%{_bindir}/curl-config
%{_datadir}/aclocal/libcurl.m4
%{_libdir}/libcurl.so
%{_includedir}/curl
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man1/curl-config.1*
%{_mandir}/man3/*

%files examples
%doc docs/examples


%changelog
* Wed Mar 27 2024 danf <danf> 1:7.88.1-4.3.mga9
+ Revision: 2052848
- Patch to fix CVE-2024-2004 and CVE-2024-2398 (mga#33020)
- Patches to fix CVE-2023-46218 and CVE-2023-46219 (mga#32599)
- Patch to fix CVE-2023-38545 & CVE-2023-38546 (mga#32362)
+ ns80 <ns80>
- add patches from Ubuntu for CVE-2023-32001 and CVE-2023-38039 (mga#31703)

* Fri Jun 02 2023 ns80 <ns80> 1:7.88.1-3.mga9
+ Revision: 1960534
- add patches from Debian for CVE-2023-28319, CVE-2023-2832[0-2] (mga#31703)

* Wed Mar 22 2023 ns80 <ns80> 1:7.88.1-2.mga9
+ Revision: 1950009
- add patches from Debian for CVE-2023-2753[3-8] (mga#31703)

* Mon Feb 20 2023 kekepower <kekepower> 1:7.88.1-1.mga9
+ Revision: 1944234
- Update to version 7.88.1

* Wed Feb 15 2023 kekepower <kekepower> 1:7.88.0-1.mga9
+ Revision: 1942580
- Update to version 7.88.0

* Wed Dec 21 2022 kekepower <kekepower> 1:7.87.0-1.mga9
+ Revision: 1925581
- Update to version 7.87.0

* Wed Oct 26 2022 kekepower <kekepower> 1:7.86.0-1.mga9
+ Revision: 1899450
- Update to version 7.86.0

* Fri Sep 16 2022 neoclust <neoclust> 1:7.85.0-2.mga9
+ Revision: 1889158
- Rebuild against new openldap

* Thu Sep 01 2022 ns80 <ns80> 1:7.85.0-1.mga9
+ Revision: 1883265
- new version 7.85 for CVE-2022-35252 (mga#30794)

* Wed Jul 06 2022 pterjan <pterjan> 1:7.84.0-2.mga9
+ Revision: 1867850
- Include sched.h to fix build on armv7hl

* Mon Jun 27 2022 kekepower <kekepower> 1:7.84.0-1.mga9
+ Revision: 1866423
- Update to version 7.84.0

* Wed May 11 2022 kekepower <kekepower> 1:7.83.1-1.mga9
+ Revision: 1857573
- Update to version 7.83.1

* Wed Apr 27 2022 kekepower <kekepower> 1:7.83.0-1.mga9
+ Revision: 1854538
- Update to versino 7.83.0

* Wed Mar 23 2022 umeabot <umeabot> 1:7.82.0-2.mga9
+ Revision: 1821253
- Mageia 9 Mass Rebuild

* Sat Mar 05 2022 kekepower <kekepower> 1:7.82.0-1.mga9
+ Revision: 1789044
- Update to version 7.82.0

* Wed Jan 05 2022 kekepower <kekepower> 1:7.81.0-1.mga9
+ Revision: 1766902
- Update to version 7.81.0

* Wed Nov 10 2021 kekepower <kekepower> 1:7.80.0-1.mga9
+ Revision: 1755598
- Update to version 7.80.0

* Fri Oct 01 2021 guillomovitch <guillomovitch> 1:7.79.1-2.mga9
+ Revision: 1747296
- rebuild for openssl 3.0.0

* Wed Sep 22 2021 luigiwalser <luigiwalser> 1:7.79.1-1.mga9
+ Revision: 1746191
- 7.79.1

* Wed Sep 15 2021 ns80 <ns80> 1:7.79.0-1.mga9
+ Revision: 1745505
- new version 7.79.0 for CVE-2021-2294[5-7] (mga#29461)

* Thu Jul 22 2021 ns80 <ns80> 1:7.78.0-1.mga9
+ Revision: 1737377
- new version 7.78.0 for CVE-2021-2292[2-5] (mga#29278)

* Thu May 27 2021 kekepower <kekepower> 1:7.77.0-1.mga9
+ Revision: 1728681
- Update to version 7.77.0

* Thu Apr 15 2021 ns80 <ns80> 1:7.76.1-1.mga9
+ Revision: 1715873
- new version 7.76.1

* Wed Mar 31 2021 kekepower <kekepower> 1:7.76.0-1.mga9
+ Revision: 1712177
- Update to version 7.76.0

* Thu Feb 25 2021 kekepower <kekepower> 1:7.75.0-1.mga9
+ Revision: 1690837
- Update to version 7.75.0

* Sun Dec 27 2020 neoclust <neoclust> 1:7.74.0-1.mga8
+ Revision: 1664294
- New version 7.74.0

* Sun Oct 25 2020 shlomif <shlomif> 1:7.73.0-1.mga8
+ Revision: 1639362
- New version 7.73.0

* Tue Oct 13 2020 shlomif <shlomif> 1:7.72.0-1.mga8
+ Revision: 1635247
- New version 7.72.0

* Thu Jul 02 2020 shlomif <shlomif> 1:7.71.1-1.mga8
+ Revision: 1601460
- New version 7.71.1

* Thu Jun 25 2020 shlomif <shlomif> 1:7.71.0-1.mga8
+ Revision: 1599263
- New version 7.71.0
+ wally <wally>
- update descriptions and summaries
- drop ldflags from curl-config output
- remove multiarch support

* Thu Apr 30 2020 danf <danf> 1:7.70.0-1.mga8
+ Revision: 1573521
- Build test programs in parallel for speed
- Remove some patchups no longer needed
+ shlomif <shlomif>
- New version 7.70.0

* Wed Mar 11 2020 kekepower <kekepower> 1:7.69.1-1.mga8
+ Revision: 1555512
- Update to version 7.69.1

* Thu Mar 05 2020 kekepower <kekepower> 1:7.69.0-1.mga8
+ Revision: 1553910
- Update to version 7.69.0

* Wed Feb 19 2020 umeabot <umeabot> 1:7.68.0-2.mga8
+ Revision: 1542964
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Jan 08 2020 shlomif <shlomif> 1:7.68.0-1.mga8
+ Revision: 1477270
- New version 7.68.0

* Wed Nov 13 2019 daviddavid <daviddavid> 1:7.67.0-1.mga8
+ Revision: 1459884
- new version: 7.67.0
- make tests/*.py use Python 3
+ shlomif <shlomif>
- New version 7.66.0

* Tue Jul 23 2019 kekepower <kekepower> 1:7.65.3-1.mga8
+ Revision: 1423590
- Update to version 7.65.3

* Sat Jun 29 2019 shlomif <shlomif> 1:7.65.1-1.mga8
+ Revision: 1416183
- New version 7.65.1

* Thu May 23 2019 shlomif <shlomif> 1:7.65.0-1.mga7
+ Revision: 1398953
- New version 7.65.0 ( MGA#23789 ).

* Fri Mar 29 2019 luigiwalser <luigiwalser> 1:7.64.1-1.mga7
+ Revision: 1381111
- 7.64.1

* Wed Feb 13 2019 luigiwalser <luigiwalser> 1:7.64.0-2.mga7
+ Revision: 1366524
- rebuild for libidn2

* Thu Feb 07 2019 shlomif <shlomif> 1:7.64.0-1.mga7
+ Revision: 1363990
- New version 7.64.0

* Mon Jan 28 2019 luigiwalser <luigiwalser> 1:7.63.0-3.mga7
+ Revision: 1361534
- add patch from fedora to fix issue like CVE-2018-20483 in wget

* Wed Jan 09 2019 wally <wally> 1:7.63.0-2.mga7
+ Revision: 1353595
- rebuild for new libidn2

* Tue Jan 01 2019 shlomif <shlomif> 1:7.63.0-1.mga7
+ Revision: 1348162
- Fix check stage
- New version 7.63.0

* Mon Dec 03 2018 tmb <tmb> 1:7.62.0-2.mga7
+ Revision: 1338099
- rebuild with new nghttpd

* Sat Nov 10 2018 shlomif <shlomif> 1:7.62.0-1.mga7
+ Revision: 1329433
- New version 7.62.0

* Wed Sep 05 2018 luigiwalser <luigiwalser> 1:7.61.1-1.mga7
+ Revision: 1257292
- 7.61.1

* Sun Jul 22 2018 daviddavid <daviddavid> 1:7.61.0-1.mga7
+ Revision: 1244772
- new version: 7.61.0

* Wed May 16 2018 kekepower <kekepower> 1:7.60.0-1.mga7
+ Revision: 1229823
- Update to version 7.60.0

* Wed May 02 2018 luigiwalser <luigiwalser> 1:7.59.0-2.mga7
+ Revision: 1224632
- build against libssh instead of libssh2 (from fedora)

* Wed Mar 14 2018 kekepower <kekepower> 1:7.59.0-1.mga7
+ Revision: 1209330
- Update to version 7.59.0

* Wed Jan 24 2018 luigiwalser <luigiwalser> 1:7.58.0-1.mga7
+ Revision: 1196706
- 7.58.0
- rediff patch 4

* Fri Dec 08 2017 wally <wally> 1:7.57.0-2.mga7
+ Revision: 1181676
- build with brotli

* Fri Dec 01 2017 luigiwalser <luigiwalser> 1:7.57.0-1.mga7
+ Revision: 1180624
- 7.57.0

* Thu Nov 16 2017 shlomif <shlomif> 1:7.56.1-2.mga7
+ Revision: 1177534
- rebuild for curl-devel found with incorrect range

* Wed Oct 25 2017 shlomif <shlomif> 1:7.56.1-1.mga7
+ Revision: 1173633
- New version 7.56.1

* Wed Oct 11 2017 wally <wally> 1:7.56.0-2.mga7
+ Revision: 1171017
- build with libpsl

* Wed Oct 11 2017 wally <wally> 1:7.56.0-1.mga7
+ Revision: 1170950
- new version 7.56.0
- build with libidn2

* Sun Sep 03 2017 pterjan <pterjan> 1:7.55.1-2.mga7
+ Revision: 1151065
- Enable test 323 again now that stunnel is fixed

* Sat Sep 02 2017 pterjan <pterjan> 1:7.55.1-1.mga7
+ Revision: 1150623
- Disable test 323 failing due to stunnel segfaulting
- Rebuild for new openssl
+ luigiwalser <luigiwalser>
- 7.55.1
+ neoclust <neoclust>
- New version 7.55.0
+ guillomovitch <guillomovitch>
- rebuild for latest openssl

* Mon Jun 19 2017 pterjan <pterjan> 1:7.54.1-2.mga6
+ Revision: 1107893
- Add upstream patch ixing a segfault introduced in 7.54.1

* Wed Jun 14 2017 luigiwalser <luigiwalser> 1:7.54.1-1.mga6
+ Revision: 1107660
- 7.54.1

* Wed Apr 19 2017 luigiwalser <luigiwalser> 1:7.54.0-1.mga6
+ Revision: 1096785
- 7.54.0 (fixes CVE-2017-7468)
- remove patch 6 (may no longer be needed)
- remove upstream CVE-2017-7407 patch

* Wed Apr 05 2017 luigiwalser <luigiwalser> 1:7.53.1-1.mga6
+ Revision: 1095934
- add upstream patch to fix CVE-2017-7407
- 7.53.1

* Wed Feb 22 2017 luigiwalser <luigiwalser> 1:7.53.0-1.mga6
+ Revision: 1087333
- 7.53.0
- rediff patch 6

* Fri Dec 23 2016 luigiwalser <luigiwalser> 1:7.52.1-1.mga6
+ Revision: 1076630
- 7.52.1

* Wed Dec 21 2016 luigiwalser <luigiwalser> 1:7.52.0-1.mga6
+ Revision: 1076294
- 7.52.0
- rediff patch 6

* Wed Nov 02 2016 luigiwalser <luigiwalser> 1:7.51.0-1.mga6
+ Revision: 1064730
- 7.51.0
- rediff patch 6

* Wed Sep 14 2016 luigiwalser <luigiwalser> 1:7.50.3-1.mga6
+ Revision: 1052886
- 7.50.3

* Wed Sep 07 2016 luigiwalser <luigiwalser> 1:7.50.2-1.mga6
+ Revision: 1050327
- 7.50.2
- rediff patch 6

* Thu Aug 04 2016 neoclust <neoclust> 1:7.50.1-2.mga6
+ Revision: 1044425
- Disable tests on arm for the moment

* Wed Aug 03 2016 luigiwalser <luigiwalser> 1:7.50.1-1.mga6
+ Revision: 1044375
- 7.50.1

* Sun Jul 31 2016 daviddavid <daviddavid> 1:7.50.0-2.mga6
+ Revision: 1044154
- add upstream patch to revert 9adf3c4 and make public types void * again
  * https://github.com/curl/curl/issues/926

* Thu Jul 21 2016 luigiwalser <luigiwalser> 1:7.50.0-1.mga6
+ Revision: 1042998
- 7.50.0

* Mon May 30 2016 luigiwalser <luigiwalser> 1:7.49.1-1.mga6
+ Revision: 1019441
- 7.49.1

* Wed May 18 2016 luigiwalser <luigiwalser> 1:7.49.0-1.mga6
+ Revision: 1016728
- rediff patch 6
- 7.49.0

* Wed Mar 23 2016 luigiwalser <luigiwalser> 1:7.48.0-1.mga6
+ Revision: 994622
- 7.48.0

* Tue Mar 15 2016 daviddavid <daviddavid> 1:7.47.1-6.mga6
+ Revision: 991020
- rename and rediff do-not-build-examples patch (since fixed autopatch)

* Wed Mar 02 2016 umeabot <umeabot> 1:7.47.1-5.mga6
+ Revision: 983179
- Rebuild for openssl

* Wed Mar 02 2016 joequant <joequant> 1:7.47.1-4.mga6
+ Revision: 983076
- rebuild with new openssl so that virtualbox doesn't fail with unknown symbol

* Thu Feb 25 2016 oden <oden> 1:7.47.1-3.mga6
+ Revision: 978876
- rebuild

* Wed Feb 24 2016 oden <oden> 1:7.47.1-2.mga6
+ Revision: 978540
- enable HTTP/2 (https://daniel.haxx.se/http2/)

* Mon Feb 08 2016 luigiwalser <luigiwalser> 1:7.47.1-1.mga6
+ Revision: 950856
- 7.47.1

* Wed Jan 27 2016 luigiwalser <luigiwalser> 1:7.47.0-1.mga6
+ Revision: 928186
- 7.47.0 (fixes CVE-2016-0755)

* Wed Dec 02 2015 luigiwalser <luigiwalser> 1:7.46.0-1.mga6
+ Revision: 907739
- 7.46.0

* Thu Nov 19 2015 luigiwalser <luigiwalser> 1:7.45.0-1.mga6
+ Revision: 904334
- 7.45.0

* Sat Aug 22 2015 tmb <tmb> 1:7.44.0-1.mga6
+ Revision: 868108
- 7.44.0
- rebuild for new gcc

* Mon Jul 06 2015 luigiwalser <luigiwalser> 1:7.43.0-2.mga6
+ Revision: 851855
- rebuild without libidn support to mitigate CVE-2015-2059

* Sat Jun 20 2015 shlomif <shlomif> 1:7.43.0-1.mga6
+ Revision: 836478
- New version 7.43.0

* Wed Jun 17 2015 luigiwalser <luigiwalser> 1:7.40.0-4.mga6
+ Revision: 823178
- add upstream patches to fix CVE-2015-3236 and CVE-2015-3237

* Wed Apr 29 2015 luigiwalser <luigiwalser> 1:7.40.0-3.mga5
+ Revision: 820853
- add upstream patch to fix CVE-2015-3153

* Wed Apr 22 2015 luigiwalser <luigiwalser> 1:7.40.0-2.mga5
+ Revision: 820538
- add upstream patches to fix CVE-2015-314[3458]

* Thu Jan 08 2015 luigiwalser <luigiwalser> 1:7.40.0-1.mga5
+ Revision: 809362
- 7.40.0 (fixes CVE-2014-8150)

* Fri Jan 02 2015 pterjan <pterjan> 1:7.39.0-2.mga5
+ Revision: 808219
- Add Fedora patch preventing configure script from discarding -g in CFLAGS

* Thu Nov 06 2014 luigiwalser <luigiwalser> 1:7.39.0-1.mga5
+ Revision: 795948
- 7.39.0
- disable unreliable test 2034

* Thu Nov 06 2014 luigiwalser <luigiwalser> 1:7.38.0-5.mga5
+ Revision: 795898
- rediff upstream patch to fix CVE-2014-3707
+ danf <danf>
- Skip flaky tests in %%check

* Wed Oct 15 2014 umeabot <umeabot> 1:7.38.0-4.mga5
+ Revision: 745554
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 1:7.38.0-3.mga5
+ Revision: 693716
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1:7.38.0-2.mga5
+ Revision: 678639
- Mageia 5 Mass Rebuild

* Wed Sep 10 2014 luigiwalser <luigiwalser> 1:7.38.0-1.mga5
+ Revision: 674545
- 7.38.0

* Thu Jul 17 2014 luigiwalser <luigiwalser> 1:7.37.1-1.mga5
+ Revision: 653461
- 7.37.1

* Wed May 21 2014 luigiwalser <luigiwalser> 1:7.37.0-1.mga5
+ Revision: 624736
- 7.37.0

* Wed Mar 26 2014 luigiwalser <luigiwalser> 1:7.36.0-1.mga5
+ Revision: 608748
- 7.36.0

* Tue Feb 04 2014 fwang <fwang> 1:7.35.0-1.mga5
+ Revision: 581451
- new version 7.35.0

* Tue Dec 17 2013 luigiwalser <luigiwalser> 1:7.34.0-1.mga4
+ Revision: 558348
- 7.34.0
- remove upstream patch

* Tue Oct 22 2013 umeabot <umeabot> 1:7.33.0-2.mga4
+ Revision: 545335
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 luigiwalser <luigiwalser> 1:7.33.0-1.mga4
+ Revision: 501156
- 7.33.0

* Mon Aug 12 2013 luigiwalser <luigiwalser> 1:7.32.0-1.mga4
+ Revision: 465943
- 7.32.0

* Sun Jun 23 2013 fwang <fwang> 1:7.31.0-1.mga4
+ Revision: 445818
- new version 7.31.0

* Fri May 24 2013 luigiwalser <luigiwalser> 1:7.30.0-1.mga4
+ Revision: 426641
- 7.30.0
- remove upstream patches 3, 7, 8, 9
- re-diff patch 4

* Fri Apr 12 2013 luigiwalser <luigiwalser> 1:7.28.1-6.mga3
+ Revision: 409817
- add upstream patch to fix CVE-2013-1944

* Wed Feb 06 2013 luigiwalser <luigiwalser> 1:7.28.1-5.mga3
+ Revision: 394891
- add upstream patch to fix CVE-2013-0249

* Fri Jan 11 2013 umeabot <umeabot> 1:7.28.1-4.mga3
+ Revision: 348491
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 sander85 <sander85> 1:7.28.1-3.mga3
+ Revision: 341227
- Comment out AC_CONFIG_MACRO_DIR to fix build
+ fwang <fwang>
- another patch
- fix build with automake 1.13

* Thu Dec 27 2012 pterjan <pterjan> 1:7.28.1-2.mga3
+ Revision: 335560
- Remove useless docdir entry breaking with new rpm

* Tue Nov 20 2012 fwang <fwang> 1:7.28.1-1.mga3
+ Revision: 319747
- new version 7.28.1

* Thu Oct 11 2012 luigiwalser <luigiwalser> 1:7.28.0-1.mga3
+ Revision: 304554
- 7.28.0

* Sat Jul 28 2012 fwang <fwang> 1:7.27.0-1.mga3
+ Revision: 275157
- rediff privlibs patch
- new version 7.27.0

* Mon May 28 2012 fwang <fwang> 1:7.26.0-1.mga3
+ Revision: 247663
- update file list
- add back patch
- fix patches
- new version 7.26.0
- examples is a noarch pacakge

* Thu Jan 26 2012 fwang <fwang> 1:7.24.0-1.mga2
+ Revision: 201713
- new version 7.24.0

* Fri Nov 25 2011 fwang <fwang> 1:7.23.1-2.mga2
+ Revision: 171781
- add lber libname
- drop .la files

* Fri Nov 18 2011 fwang <fwang> 1:7.23.1-1.mga2
+ Revision: 168658
- new version 7.23.1

* Wed Nov 16 2011 fwang <fwang> 1:7.23.0-1.mga2
+ Revision: 168062
- new version 7.23.0

* Wed Sep 14 2011 fwang <fwang> 1:7.22.0-1.mga2
+ Revision: 143120
- new version 7.22.0

* Wed Jul 06 2011 dams <dams> 1:7.21.7-1.mga2
+ Revision: 119481
- update to 7.21.7
- avoid pulling 32-bit librairies on 64-bit arch

* Thu Jun 09 2011 dams <dams> 1:7.21.6-1.mga2
+ Revision: 102379
- update to 7.21.6 to fix --version

* Wed Apr 20 2011 pterjan <pterjan> 1:7.21.5-1.mga1
+ Revision: 89223
- Update to 7.21.5

* Wed Apr 13 2011 tv <tv> 1:7.21.4-1.mga1
+ Revision: 84544
- new release
- drop patch 1

* Sun Jan 09 2011 blino <blino> 1:7.21.2-2.mga1
+ Revision: 3738
- remove old version checks and ldconfig scriptlets
+ kharec <kharec>
- imported package curl

